# Contribution Guidelines

See more extensive details here: [developer documentation](https://erin2722.github.io/usau-scraper/developer.html)

## Prerequrisites 

Make sure python (3.7+) and pip are installed.

## To Start Developing

Download the library: `https://github.com/erin2722/usau-scraper.git`

Install development dependencies: `make develop`

To run tests: `make test`

## Submitting a PR

Before submitting a PR, make sure that the linter and all tests pass:

To autoformat: `make format`

To lint: `make lint`

Please make sure to add new tests for any new features you add. Code coverage should remain at about the same level
before and after your PR.
